==> dojo-1.9.4.tgz: package/cldr/nls/zh/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"field-weekday": "星期",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"希伯来历"
	],
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormat-long": "Gy年M月d日",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-yyyyMEd": "Gy-M-d（E）",
	"dateFormatItem-Md": "M-d",
	"field-era": "时期",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"timeFormat-long": "zah:mm:ss",
	"field-year": "年",
	"field-hour": "小时",
	"months-format-abbr-leap": "闰7月",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"timeFormat-full": "zzzzah:mm:ss",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "后天",
	"dateFormatItem-H": "H时",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"months-standAlone-wide-leap": "闰七月",
	"timeFormat-medium": "ah:mm:ss",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"eraAbbr": [
		"希伯来历"
	],
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah时",
	"dateTimeFormat-long": "{1}{0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M-dE",
	"dateTimeFormat-full": "{1}{0}",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "时区",
	"months-standAlone-abbr-leap": "闰7月",
	"dateFormatItem-y": "Gy年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-hm": "ah:mm",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"eraNames": [
		"希伯来历"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-yyyyMd": "Gy-M-d",
	"field-month": "月",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-wide-am": "上午",
	"dateFormat-short": "Gy-M-d",
	"field-second": "秒钟",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "Gy年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"dateFormatItem-yyyyM": "Gy-M",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"dateFormatItem-hms": "ah:mm:ss",
	"months-format-wide-leap": "闰七月",
	"dateFormatItem-GyMMM": "Gy年M月",
	"dateFormatItem-yyyy": "Gy年",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/zh/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"field-second-relative+0": "现在",
	"field-weekday": "工作日",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"希伯来历"
	],
	"field-tue-relative+-1": "上周二",
	"days-format-short": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormat-long": "Gy年M月d日",
	"field-fri-relative+-1": "上周五",
	"field-wed-relative+-1": "上周三",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-yyyyMEd": "Gy/M/dE",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-wide-noon": "中午",
	"field-era": "纪元",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"timeFormat-long": "z ah:mm:ss",
	"field-year": "年",
	"field-hour": "小时",
	"months-format-abbr-leap": "闰7月",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"timeFormat-full": "zzzz ah:mm:ss",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本周四",
	"field-day-relative+1": "明天",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "后天",
	"dateFormatItem-H": "H时",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"quarters-format-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"months-standAlone-wide-leap": "闰七月",
	"timeFormat-medium": "ah:mm:ss",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"eraAbbr": [
		"希伯来历"
	],
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah时",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M/dE",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "时区",
	"months-standAlone-abbr-leap": "闰7月",
	"dateFormatItem-y": "Gy年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-hm": "ah:mm",
	"days-format-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"eraNames": [
		"希伯来历"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-month": "月",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"dayPeriods-format-wide-am": "上午",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"dateFormat-short": "Gy-M-d",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒钟",
	"field-sat-relative+-1": "上周六",
	"field-sun-relative+-1": "上周日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "Gy年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"dateFormatItem-yyyyM": "Gy年M月",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
	"dateFormatItem-hms": "ah:mm:ss",
	"months-format-wide-leap": "闰七月",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-yyyy": "Gy年",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);
